
// DynaM3G.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, August 2005

/* Illustrates the use of DynaBoard, a billboard whose image is
   generated dynamically at run time. The image can be anything 
   that can be drawn using Graphics operations. The
   resulting texture on the board can have transparent parts.

   The camera can be moved around, and rotated, via arrow key presses.
   The camera's mode of movement is controlled by the 'select' key.

   The code here reuses large parts of the AnimM3G example. For
   example, the Floor class is the same as the one in AnimM3G.

   DynaBoard is a variant of AnimBillboard in GunnerM3G.
*/

import javax.microedition.lcdui.*;
import javax.microedition.midlet.*;
import java.util.*;


public class DynaM3G extends MIDlet
{
  private static final int PERIOD = 50;   // in ms

  private Timer timer;
  private DynaCanvas dynaCanvas = null;

  public DynaM3G()
  { timer = new Timer();  
    dynaCanvas = new DynaCanvas(this); 
  }


  public void startApp() 
  { Display.getDisplay(this).setCurrent( dynaCanvas );
    timer.schedule( new DynaTimer(), 0, PERIOD);   // tick every PERIOD ms
  }
  
  public void pauseApp() {}

  public void destroyApp(boolean unconditional) {}

  public void finishGame()
  { timer.cancel();    // stop the timer
    notifyDestroyed();  
  }


  // -------------------------------------------

  class DynaTimer extends TimerTask 
  {
    public void run() 
    { if(dynaCanvas != null)
        dynaCanvas.update();   // update the scene
    }
  }

} // end of DynaM3G class
